#!/usr/bin/env python3
# Copyright 2021 Canonical Ltd.
# See LICENSE file for licensing details.
#
# Learn more at: https://juju.is/docs/sdk

"""Charm the service.

Refer to the following post for a quick-start guide that will help you
develop a new k8s charm using the Operator Framework:

    https://discourse.charmhub.io/t/4208
"""

import logging
import traceback

from ops.charm import CharmBase
from ops.main import main
from ops.model import ActiveStatus

from snap_proxy_overrides import update_snap_overrides

logger = logging.getLogger(__name__)


class SnapProxyOverridesCharm(CharmBase):
    """Charm the service."""

    def __init__(self, *args):
        super().__init__(*args)
        self.framework.observe(self.on.update_status, self._on_update_status)
        self.framework.observe(self.on.pin_revisions_action, self._on_pin_revisions_action)

    def _on_update_status(self, _):
        self.unit.status = ActiveStatus("OK")

    def _on_pin_revisions_action(self, event):
        snaps = self.config["snaps"].split(',')
        try:
            update_snap_overrides(snaps)
            event.set_results({'result': 'OK'})
        except Exception:
            event.fail(traceback.format_exc())


if __name__ == "__main__":
    main(SnapProxyOverridesCharm)
